@@ -2,6 +2,7 @@ use strict;
 use warnings;
 
 package XML::Enc;
+our $VERSION = '0.06'; # VERSION
 
 # ABSTRACT: XML::Enc Encryption Support
 
@@ -9,14 +10,12 @@ use Carp;
 use XML::LibXML;
 use Crypt::OpenSSL::RSA;
 use Crypt::Mode::CBC;
-use Crypt::AuthEnc::GCM;
+use Crypt::AuthEnc::GCM 0.062;
 use MIME::Base64 qw/decode_base64 encode_base64/;
 use Crypt::Random qw( makerandom_octet );
 
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
-our $VERSION = '0.05';
-
 our $DEBUG = 0;
 
 
@@ -779,7 +778,7 @@ XML::Enc - XML::Enc Encryption Support
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
